@@ -3,5 +3,5 @@ import { createContext } from "@lit/context";
 import type { WizardStepState } from "./types";
 
 export const wizardStepContext = createContext<WizardStepState>(
-    Symbol("authentik-wizard-step-labels"),
+    Symbol.for("authentik-wizard-step-labels"),
 );
